/* eslint-disable react-hooks/exhaustive-deps */
"use client";

import { useEffect, useState } from "react";
import { useRouter } from "next/navigation";
import Loader from "@/components/Loader";
import Header from "@/components/Header";
import { useLocalStorage } from "@/hooks/useLocalStorage";

export default function ProtectedLayout({ children }: { children: React.ReactNode }) {
  const [isLoading, setIsLoading] = useState(true);
  const router = useRouter();
  const { getFromStorage, deleteFromStorage } = useLocalStorage();

  const logoutRedirect = () => {
    deleteFromStorage('token'); 
    deleteFromStorage('tokenExpiry');
    return router.push("/login")
  }

  useEffect(() => {
    const token = getFromStorage('token');
    const tokenExpiry = getFromStorage('tokenExpiry');
    
    if (!token || !tokenExpiry) {
      return logoutRedirect();
    }

    const expiryDate = new Date(tokenExpiry);

    if (isNaN(expiryDate.getTime())) {
      return logoutRedirect();
    } 

    const now = new Date();

    const isExpired = (now.getTime() - expiryDate.getTime()) > 24 * 60 * 60 * 1000;
    
    if (isExpired) {
      return logoutRedirect();
    }

    setIsLoading(false);
  }, []);

  if(isLoading) return <Loader loaderType="page" />

  return (
    <div className="w-full h-full flex flex-col">
      <Header />
      {children}
    </div>
  );
}
