"use server";

import axios from "axios";

interface GetAddressFromCoordinatesProps {
  lat: number;
  lng: number;
}

export async function getAddressFromCoordinates({
  lat,
  lng,
}: GetAddressFromCoordinatesProps) {
  try {
    const response = await axios.get(
      "https://maps.googleapis.com/maps/api/geocode/json",
      {
        params: {
          latlng: `${lat},${lng}`,
          key: process.env.NEXT_PUBLIC_API_KEY,
        },
      }
    );

    const data = response.data;

    if (data.status === "OK" && data.results.length > 0) {
      const addressComponents = data.results[0].address_components;
      const address = data.results[0].formatted_address;
      const cep =
        addressComponents.find((component: { types: string[] }) =>
          component.types.includes("postal_code")
        )?.long_name || "";
      const state =
        addressComponents.find((component: { types: string[] }) =>
          component.types.includes("administrative_area_level_1")
        )?.short_name || "";

      return {
        address,
        cep,
        state,
      };
    }

    return {
      message: "Endereço não encontrado.",
      status: 404,
    };
  } catch (error) {
    if (axios.isAxiosError(error)) {
      const apiErrorMessage =
        error.response?.data?.error_message || "Erro desconhecido na API";
      return {
        message: apiErrorMessage,
        status: error.response?.status || 500,
      };
    }

    return {
      message: `Erro desconhecido: ${error}`,
    };
  }
}
