"use server";

import axios from "axios";

interface GetCoordinatesProps {
  address: string;
  cep: string;
  state: string;
}

export async function getCoordinates({ address, cep, state }: GetCoordinatesProps) {
  const fullAddress = `${address}, ${cep}, ${state}`;

  try {
    const response = await axios.get('https://maps.googleapis.com/maps/api/geocode/json', {
      params: {
        address: fullAddress,
        key: process.env.NEXT_PUBLIC_API_KEY,
      },
    });

    return {
      data: response.data,
    };
  } catch (error) {
    if (axios.isAxiosError(error)) {
      const apiErrorMessage =
        error.response?.data?.error_message || "Erro desconhecido na API";
      return {
        message: apiErrorMessage,
        status: error.response?.status || 500,
      };
    }

    return {
      message: `Erro desconhecido: ${error}`,
    };
  }
}
