import { ButtonHTMLAttributes } from "react";
import styles from "@/styles/components/button.module.css";

export interface ButtonProps extends ButtonHTMLAttributes<HTMLButtonElement> {
  variant: "default" | "light";
}

export default function Button({
  variant,
  disabled,
  children,
  className,
  ...buttonProps
}: ButtonProps) {
  const buttonClasses = [
    styles["button-default"],
    variant === "default"
      ? styles["button-variant-default"]
      : styles["button-variant-light"],
    disabled ? styles["button-disabled"] : "",
    className,
  ].join(" ");

  return (
    <button disabled={disabled} className={buttonClasses} {...buttonProps}>
      {children}
    </button>
  );
}
