import React, { useState } from "react";
import Image from "next/image";
import { PlusSquare } from "@geist-ui/react-icons";
import styles from "@/styles/components/contentCard.module.css";
import SearchIcon from "../app/assets/search-icon.png";
import ModalRegisterEdit from "./RegisterContentModal";

interface ContentCardProps {
  title: string;
  placeholder: string;
  children: React.ReactNode;
  searchTerm: string;
  onSearchChange: (value: string) => void;
}

export default function ContentCard({
  title,
  placeholder,
  children,
  searchTerm,
  onSearchChange,
}: ContentCardProps) {
  const [isModalOpen, setIsModalOpen] = useState(false);

  const closeModal = () => {
    setIsModalOpen(false);
  };

  return (
    <div className={styles.container}>
      <div className={styles.section}>
        <div className={styles.content}>
          <div className={styles.contentHeader}>
            <h1>{title}</h1>
            <div className={styles.searchContainer}>
              <div className={styles.searchWrapper}>
                <Image
                  src={SearchIcon}
                  alt="searchIcon"
                  className={styles.searchIcon}
                  width={20}
                  height={20}
                />
                <input
                  type="text"
                  className={styles.searchInput}
                  placeholder={placeholder}
                  value={searchTerm}
                  onChange={(e) => onSearchChange(e.target.value)}
                />
              </div>
            </div>
            <button
              className={styles.newButton}
              onClick={() => setIsModalOpen(true)}
            >
              <PlusSquare className={styles.buttonIcon} size={16} />
              <span className={styles.buttonText}>Cadastrar</span>
            </button>
          </div>
          {children}
        </div>
      </div>
      <ModalRegisterEdit isOpen={isModalOpen} onClose={closeModal} refreshPosts={function (): void {
        throw new Error("Function not implemented.");
      } } />
    </div>
  );
}
