/* eslint-disable react/jsx-key */
import { fetchPost } from "@/app/_actions/posts/fetch-post";
import Modal from "@/components/Modal";
import { Feedback } from "@/interfaces/feedback";
import { useEffect, useState } from "react";
import { toast } from "sonner";

import styles from "@styles/components/feedback.modal.module.css";
import { ThumbsDown, ThumbsUp } from "@geist-ui/icons";
import Loader from "./Loader";

interface FeedBackModalProps {
  isOpen: boolean;
  onClose: () => void;
  post_id: string;
}

export default function FeedBackModal({ isOpen, onClose, post_id }: FeedBackModalProps) {
  const [isLoading, setIsLoading] = useState(false);
  const [feedBacks, setFeedBacks] = useState<Feedback[]>([]);

  useEffect(() => {
    if (!isOpen) return;

    setIsLoading(true);

    fetchPost(post_id)
      .then((response) => {
        if (response.message) {
          toast.error(response.message);
          return;
        }

        const { feedbacks } = response.data;

        setFeedBacks(feedbacks);
      })
      .catch(() => {
        toast.error("Erro desconhecido.");
      })
      .finally(() => {
        setIsLoading(false);
      });
  }, [isOpen, post_id]);

  return (
    <Modal
      isOpen={isOpen}
      onClose={onClose}
      title="Avaliações do conteúdo"
    >
      <div>
        {isLoading ? (
          <Loader loaderType="component" />
        ) : feedBacks.length === 0 ? (
          <p className={styles.notFoundMessage}>Este conteúdo ainda não possui feedbacks.</p>
        ) : (
          <div className={styles.feedbackList}>
            {feedBacks.map((feedback) => (
              <div className={styles.feedbackItem}>
                <p>{feedback.comment}</p>
                <span className={styles.feedbackIcon}>
                  {feedback.hasLiked ? (
                    <ThumbsUp color="green" />
                  ) : (
                    <ThumbsDown color="red" />
                  )}
                </span>
              </div>
            ))}
          </div>
        )}
      </div>
    </Modal>
  );
}
