import React from "react";
import styles from "@/styles/components/FeedbackVisualization.module.css";
import { ThumbsDown, ThumbsUp } from "@geist-ui/icons";
import { Feedback } from "@/types/post";
import CancelIcon from "@/app/assets/cancel-icon.png";
import Image from "next/image";
import StringTokens from "@/utils/stringTokens";


interface FeedbackVisualizationModalProps {
  feedbacks: Feedback[];
  onClose: () => void;
}

const tokens = StringTokens();

const FeedbackVisualizationModal: React.FC<FeedbackVisualizationModalProps> = ({
  feedbacks,
  onClose,
}) => {
  return (
    <div className={styles.modalOverlay}>
      <div className={styles.modalContent}>
        <div className={styles.headerContent}>
          <h2 className={styles.ratingTitle}>Avaliações do conteúdo</h2>
          <button onClick={onClose} className={styles.closeButton}>
            <Image
              src={CancelIcon}
              alt={tokens.buttons.close}
              className={styles.closeIcon}
            />
          </button>
        </div>
        {feedbacks.length === 0 ? (
          <p>Este conteúdo ainda não possui feedbacks.</p>
        ) : (
          <div className={styles.feedbackList}>
            {feedbacks.map((feedback) => (
              <div key={feedback.id} className={styles.feedbackItem}>
                <p>{feedback.comment}</p>
                <span className={styles.feedbackIcon}>
                  {feedback.hasLiked ? (
                    <ThumbsUp color="green" />
                  ) : (
                    <ThumbsDown color="red" />
                  )}
                </span>
              </div>
            ))}
          </div>
        )}
      </div>
    </div>
  );
};

export default FeedbackVisualizationModal;