/* eslint-disable @typescript-eslint/no-unused-vars */
import { InputHTMLAttributes, useState } from "react";
import { UseFormRegisterReturn } from "react-hook-form";
import { AiFillEye, AiFillEyeInvisible } from "react-icons/ai";

import styles from "@/styles/components/input.module.css";
import { Masks } from "@/types/masks";
import { maskCEP } from "@/utils/mask-cep";

interface CustomInputProps extends InputHTMLAttributes<HTMLInputElement> {
  label?: string;
  errorMessage?: string;
  register: UseFormRegisterReturn;
  mask?: Masks;
}

export default function CustomInput({
  label,
  errorMessage,
  register,
  type,
  value,
  onChange,
  mask,
  ...inputProps
}: CustomInputProps) {
  const [showPassword, setShowPassword] = useState(false);

  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  const masksActions: Record<Masks, (value: string) => string> = {
    cep: (value: string) => maskCEP(value),
  };

  const handleInputChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    const { value } = event.target;
    let maskedValue = value;

    if (mask && masksActions[mask]) {
      maskedValue = masksActions[mask](value);
    }

    event.target.value = maskedValue;

    register.onChange({
      target: {
        name: event.target.name,
        value: maskedValue,
      },
    });
  };

  return (
    <div className={styles.container}>
      <label className={styles.label}>
        <span className={styles.labelText}>{label}</span>
        <div className={styles.inputWrapper}>
          <input
            {...register}
            className={styles.input}
            type={type === "password" && showPassword ? "text" : type}
            value={value}
            onChange={handleInputChange}
            {...inputProps}
          />
          {type === "password" && (
            <button
              type="button"
              onClick={togglePasswordVisibility}
              className={styles.toggleButton}
              tabIndex={-1}
            >
              {showPassword ? (
                <AiFillEyeInvisible size={20} />
              ) : (
                <AiFillEye size={20} />
              )}
            </button>
          )}
        </div>
      </label>
      {errorMessage && (
        <span className={styles.errorMessage}>{errorMessage}</span>
      )}
    </div>
  );
}
