/* eslint-disable @typescript-eslint/no-unused-vars */
'use client'

import { toast } from 'sonner'
import React, { useState } from 'react'
import { BiPencil, BiTrash } from 'react-icons/bi'

import { PointOfInterest } from '@/interfaces/point-of-interest'

import DeleteModal from '@/components/DeleteModal'
import styles from '@styles/components/table.contained.module.css'
import { deletePoint } from '@/app/_actions/points/delete-point'

interface TablePointsOfInterestProps {
  points: PointOfInterest[];
  refreshPoints: () => void;
  onEditPoint: (pointId: string, postId: string) => void;
}

export default function TablePointsOfInterest({ points, refreshPoints, onEditPoint }: TablePointsOfInterestProps) {
  const [pointId, setPointId] = useState<string | null>(null);
  const [postId, setPostId] = useState<string | null>(null);
  const [showModal, setShowModal] = useState({
    showDeleteModal: false,
  });

  const { showDeleteModal } = showModal;

  const handleShowModal = (modalKey: keyof typeof showModal, point_id?: string, post_id?: string) => {
    setShowModal((prevState) => ({
      ...prevState,
      [modalKey]: !prevState[modalKey],
    }));
  
    if (point_id) setPointId(point_id);
    if (post_id) setPostId(post_id);
  };
  

  const handleDeletePoint = () => {
    deletePoint(pointId as string)
      .then((response) => {
        if (response.message) return toast.error(response.message);

        toast.success("Ponto de Interesse deletado com sucesso!");

        setTimeout(() => {
          refreshPoints();
          handleShowModal("showDeleteModal");
        });
      })
      .catch(() => {
        toast.error("Erro desconhecido.");
      });
  };

  return (
    <div className={styles.tableContainer}>
      <table className={styles.table}>
        <thead>
          <tr>
            <th>Título</th>
            <th>Descrição</th>
            <th className={styles.actionsHeader}></th>
          </tr>
        </thead>
        <tbody>
          {points.map((point) => (
            <tr key={point.id}>
              <td className={styles.cell}>{point.titulo}</td>
              <td className={styles.cell}>{point.descricao}</td>
              <td className={styles.actions}>
                <button
                  onClick={() => handleShowModal("showDeleteModal", point.postId)}
                  className={styles.actionButton}
                >
                  <BiTrash size={20} />
                </button>
                <button
                  onClick={() => onEditPoint(point.id, point.postId as string)}
                  className={styles.actionButton}
                >
                  <BiPencil size={20} />
                </button>
              </td>
            </tr>
          ))}
        </tbody>
      </table>
      <DeleteModal
        isOpen={showDeleteModal}
        onClose={() => {
          handleShowModal("showDeleteModal");
          setPointId(null);
        }}
        title="Você tem certeza que deseja excluir o Ponto de Interesse?"
        description="Essa ação não pode ser desfeita. O conteúdo será permanentemente deletado e não irá ser exibido para os usuários."
        onConfirm={handleDeletePoint}
      />
    </div>
  );
}
