import { useEffect, useState } from "react";

export default function useDebounce<T>(value: T, delay = 600) {
  const [debouncedValue, setDebouncedValue] = useState<T>(value);

  useEffect(() => {
    const timeout = setTimeout(() => {
      setDebouncedValue(value);
    }, delay)

    return () => clearTimeout(timeout);
  }, [value, delay])

  return debouncedValue;
}