import { z } from "zod";

const fieldTranslations: Record<string, string> = {
  address: "Endereço",
  addressTitle: "Título do endereço",
  addressDescription: "Descrição do endereço",
  zipCode: "CEP",
  state: "Estado",
};

export const pointOfInteresSchema = z.object({
  address: z.string().optional(),
  title: z.string().optional(),
  description: z.string().optional(),
  zipCode: z.string().optional(),
  state: z.string().optional(),
}).superRefine((data, ctx) => {
  const isAnyFieldFilled = Object.values(data).some((value) => value?.trim());

  if (isAnyFieldFilled) {
    Object.entries(data).forEach(([key, value]) => {
      if (!value?.trim()) {
        const translatedField = fieldTranslations[key] || key;
        ctx.addIssue({
          code: z.ZodIssueCode.custom,
          path: [key as keyof typeof data],
          message: `${translatedField} é obrigatório`,
        });
      }
    });
  }
});

export const registerContentSchema = z.object({
  title: z.string().min(1, 'Título é obrigatório'),
  description: z.string().min(1, 'Descrição é obrigatória'),
  addressData: pointOfInteresSchema.optional(),
  categories: z.array(z.string()).min(1, 'Selecione pelo menos uma categoria.'),
  image: z.string().nullable().optional()
});
